#!/bin/ksh
#-----------------------------------------------------------------------------
# Project    : Tutoriels - Conception de circuits intégrés numériques
#-----------------------------------------------------------------------------
# File       : sim_atpg.fullscan.sh
# Authors    : Erika Miller-Jolicoeur <erika.miller-jolicoeur@polymtl.ca>
# Lab        : GRM - Polytechnique Montréal
# Date       : <2020-08-14>
#-----------------------------------------------------------------------------
# Description: Script pour les simulations des vecteurs de test du compteur BCD 
#              avec xrun
# HOW-TO     : source setup.csh && cd simulation/
#            : ../scripts/sim_atpg.fullscan.sh
#-----------------------------------------------------------------------------

DO_SYN=0
DO_PNR=1

export DESIGN=compteur

# Override step from command line if exist
if [[ $1 = "syn" ]]; then
    DO_SYN=1
    DO_PNR=0
elif [[ $1 = "pnr" ]]; then
    DO_SYN=0
    DO_PNR=1
fi

# Setup paths
if [[ $DO_SYN -eq 1 && $DO_PNR -eq 0 ]];then
    export WORKDIR=${ATPG_DIR}/syn
    export net=${SYN_DFT_NET_DIR}/${DESIGN}.syn
    export LOGDIR=syn_dft
elif [[ $DO_SYN -eq 0 && $DO_PNR -eq 1 ]];then
    export WORKDIR=${ATPG_DIR}/pnr
    export net=${PNR_DFT_NET_DIR}/${DESIGN}.route
    export LOGDIR=pnr_dft
else
    echo "Erreur de configuration du mode d'opération POST-SYNTÈSE ou POST-ROUTAGE"
    exit
fi
 
xrun \
   +access+rwc \
   +xmstatus \
   +xm64bit \
   +TESTFILE1=$WORKDIR/testresults/verilog/FULLSCAN_PARALLEL/VER.FULLSCAN.data.scan.ex1.ts1.verilog \
   +TESTFILE2=$WORKDIR/testresults/verilog/FULLSCAN_PARALLEL/VER.FULLSCAN.data.logic.ex1.ts2.verilog \
   +TESTFILE2=$WORKDIR/testresults/verilog/FULLSCAN_PARALLEL/VER.FULLSCAN.data.logic.ex1.ts3.verilog \
   +TESTFILE2=$WORKDIR/testresults/verilog/FULLSCAN_PARALLEL/VER.FULLSCAN.data.logic.ex1.ts4.verilog \
   +TESTFILE2=$WORKDIR/testresults/verilog/FULLSCAN_PARALLEL/VER.FULLSCAN.data.IDDq.ex1.ts5.verilog \
   +HEARTBEAT \
   +FAILSET \
   +xmtimescale+1ns/1ps \
   +xmoverride_timescale \
   +xmseq_udp_delay+2ps \
   +libext+.v+.V+.z+.Z+.gz \
   +xmlibdirname+$WORKDIR/Inca_libs_15_52_42 \
   -l $LOGDIR/ncverilog_FULLSCAN.log \
  -v /CMC/kits/GPDK45/gsclib045/gsclib045/verilog/fast_vdd1v0_basicCells.v \
     ${net}.v \
     $WORKDIR/testresults/verilog/FULLSCAN_PARALLEL/VER.FULLSCAN.mainsim.v

